import { useRef, useEffect } from "preact/compat";

interface RefOutsideClickInterface {
  onOutsideClick: Function,
  children: any
}

/**
 * https://stackoverflow.com/questions/32553158/detect-click-outside-react-component
 */
function useRefOutsideClick(ref: any, onOutsideClick: Function) {
  useEffect(() => {
    function handleClickOutside(event: MouseEvent) {
      if (ref.current && !ref.current.contains(event.target)) {
        onOutsideClick()
      }
    }
    // Bind the event listener
    document.addEventListener("mousedown", handleClickOutside);
    return () => {
      // Unbind the event listener on clean up
      document.removeEventListener("mousedown", handleClickOutside);
    };
  }, [ref]);
}

/**
 * Component that alerts if you click outside of it
 */
function RefOutsideClick(props: RefOutsideClickInterface) {
  const wrapperRef = useRef(null);
  useRefOutsideClick(wrapperRef, props.onOutsideClick);

  return <div ref={wrapperRef}>{props.children}</div>;
}

export default RefOutsideClick;
